@@ -13,7 +13,7 @@ from inspect import isclass
 from .plugins.plugin import JobServerPlugin
 import mprov_jobserver.plugins
 import glob
-
+import multiprocessing
 
 
 class JobServer ():
@@ -279,6 +279,9 @@ class JobServer ():
         'jobmodules': self.jobmodules,
         'one_minute_load': os.getloadavg()[0]
     }
+    if data['one_minute_load'] >= multiprocessing.cpu_count():
+      print("Not Registering, high load.")
+      return
     # print(self.config_data)
     if 'mprov-webserver' in self.config_data:
     # if  self.config_data['mprov-webserver']:
@@ -354,8 +357,8 @@ class JobServer ():
         # get the sock from the session
         s = socket.fromfd(response.raw.fileno(), socket.AF_INET, socket.SOCK_STREAM)
         # get the address from the socket
-        address, _ = s.getsockname()
-        self.ip_address=address
+        sockinfo = s.getsockname()
+        self.ip_address=sockinfo[0]
       
     # if we get a response.status_code == 200, we're ok.  If not,
     # our auth failed.
